@@ -3,6 +3,7 @@ package Data::Text;
 use warnings;
 use strict;
 use Carp;
+use String::Util;
 
 =head1 NAME
 
@@ -10,11 +11,11 @@ Data::Text - Class to handle text in an OO way
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -114,6 +115,20 @@ sub length {
 	return length($self->{'text'});
 }
 
+=head2	trim
+
+Removes leading and trailing spaces from the string.
+
+=cut
+
+sub trim {
+	my $self = shift;
+
+	$self->{'text'} = String::Util::trim($self->{'text'});
+
+	return $self
+}
+
 =head1 AUTHOR
 
 Nigel Horne, C<< <njh at bandsman.co.uk> >>
